@@ -6,7 +6,7 @@ from log import log
 from datetime import datetime
 from func_timeout import func_set_timeout
 from func_timeout.exceptions import FunctionTimedOut
-from paramiko.ssh_exception import SSHException
+from paramiko import SSHException
 
 
 class ExecResult():
@@ -48,9 +48,10 @@ class SSHClient(object):
 
     @property
     def is_sshable(self):
-        ssh = paramiko.SSHClient()
-        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+        ssh = None
         try:
+            ssh = paramiko.SSHClient()
+            ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
             ssh.connect(
                 self.__ip,
                 port=self.__port,
@@ -61,14 +62,17 @@ class SSHClient(object):
                 timeout=self.__connect_timeout
             )
             return True
-        except paramiko.ssh_exception.SSHException as e:
-            log.warning(f"{self.__ip}:{self.__port} | cannot create ssh session.")
+        except SSHException as e:
+            log.warning(f"{self.__ip}:{self.__port} | cannot create ssh session, err msg is {str(e)}.")
             return False
         except Exception as e:
             log.warning(f"{self.__ip}:{self.__port} | server is not sshable.")
             return False
         finally:
-            ssh.close()
+            try:
+                ssh.close()
+            except Exception as e:
+                pass
 
     def wait_for_sshable(self, timeout=60):
         count=0
